@@ -501,7 +501,6 @@ sub insert # InsertNode
   if( $Node->{Name} )
   {
     &{$_}( $Node ) foreach @{$uHTML::uCode{ $Node->{Name} }} ;
-    print STDERR "Inserting $Node->{Name} (".$Node->attr('id').")\n" if $Node->{Parent}->{Name} eq "body" ;
 
     delete $Node->{HTML} ;  # if $Text ;
 
@@ -550,7 +549,6 @@ sub process()  #ProcessNode
 
   if( $Node->{Name} )
   {
-    print STDERR "Process $Node->{Name} (${\($Node->attr('id'))})\n"  if $Node->{Parent}->{Name} eq "body" or $Node->{Name} eq "Scramble" or $Node->{Name} eq "DocBody" ;
     if( ref $uHTML::uTag{ $Node->{Name} } eq 'CODE' )
     {
       ref eq 'CODE' and &{$_}( $Node ) foreach @{$uHTML::uCode{ $Node->{Name} }} ;
@@ -566,7 +564,6 @@ sub process()  #ProcessNode
     {
       $Node->insert() ;
     }
-    print STDERR "Processed $Node->{Name} (${\($Node->attr('id'))})\n"  if $Node->{Parent}->{Name} eq "body" or $Node->{Name} eq "Scramble" or $Node->{Name} eq "body" or $Node->{Name} eq "DocBody" ;
   }
 
   push @{$Node->{HTML}},$Node->{Trailer} if $Node->{Trailer} ne '' ;
@@ -1176,11 +1173,11 @@ Check if some code is bound to the tag $Name.
 
 Check if some code is bound to the attribute variable $Name.
 
-    uHTML::FileStart
+    uHTML::fileStart
 
 Set the current file name for debug output. Ignored in production mode.
 
-    uHTML::FileEnd
+    uHTML::fileEnd
 
 Reset the current file name for debug output to the previous name. Ignored in production mode.
 
