@@ -22,7 +22,7 @@ use strict ;
 
 package uHTML::std ;
 
-use version ; our $VERSION = "2.30" ;
+use version ; our $VERSION = "2.32" ;
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -402,9 +402,9 @@ sub _checkMacro( $$ )
     $env->{'uHTML.MacroVal'}  = \%MacroVal ; #$MACROS{$env->{'HTTP_HOST'}}->{'MacroVal'} ;
     $env->{'uHTML.MacroHTML'} = \%MacroHTML ;#$MACROS{$env->{'HTTP_HOST'}}->{'MacroHTML'} ;
     $env->{'uHTML.MacroBody'} = \%MacroBody ;#$MACROS{$env->{'HTTP_HOST'}}->{'MacroBody'} ;
+    return undef ;
   }
 
-
   return $env->{'uHTML.Macros'}->{$Name} ;
 }
 
@@ -458,47 +458,37 @@ sub _DoMacro( $ )
   $Node->testAttr( $_ ) or $Node->setAttr( $_,$env->{'uHTML.MacroVal'}->{$Name}->{$_} ) foreach @{$env->{'uHTML.MacroAttr'}->{$Name}} ;
   print STDERR "Execute macro $Name(${\(join ',',map \"$_='${\($Node->attr($_))}'\",keys %{$Node->attributes()})})\n" if $DEBUG > 0 ;
 
+  Define( $Node ) ;
   if( $env->{'uHTML.MacroBody'}->{$Name} )
   {
     $Node->map( '','' ) ;
-    Define( $Node ) ;
     $Macro->map( '','' ) ;
-    ClearDef( $Node ) ;
     my( $H,$T ) = split m/<MacroBody>/s,$Macro->HTML(),2 ;
-    $T =~ s/<MacroBody>//sg ;
     unshift @{$Node->{HTML}},$H ;
     push    @{$Node->{HTML}},$T ;
   }
   else
   {
-    Define( $Node ) ;
     $Macro->map( '','' ) ;
-    ClearDef( $Node ) ;
     $Node->{HTML} = $Macro->{HTML} ;
   }
+  ClearDef( $Node ) ;
 }
 
-#
-#
-#
-#
-#
-#   else
-
 sub _findMacroBody
 {
   my $Node = shift ;
 
   return undef unless $Node->firstChild() ;
 
-  my( $Child,$Body ) ;
+  my( $Child,$MBody ) ;
 
   for( $Child = $Node->firstChild() ; $Child ; $Child=$Child->next() )
   {
-    return $Child if $Child->name() eq 'MacroBody' ;
-    return $Body  if $Body = _findMacroBody( $Child ) ;
+    $MBody ? $Child->delete()         : ($MBody = $Child) if $Child->name() eq 'MacroBody' ;
+    $MBody ? _findMacroBody( $Child ) : ($MBody = _findMacroBody( $Child )) ;
   }
-  return undef ;
+  return $MBody ;
 }
 
 sub Macro( $ )
@@ -511,7 +501,8 @@ sub Macro( $ )
   return unless $Node->end() and $Name = $Node->attr( 'name' ) ;
   return if     $Replace = _checkMacro( $env,$Name ) and not $Node->testAttr( 'replace' ) ;
   print STDERR "Define Macro '$Name\(${\($Node->attr( 'attributes' ))}\)'\n" if $DEBUG > 1 ;
-  $env->{'uHTML.MacroBody'}->{$Name} = _findMacroBody( $env->{'uHTML.Macros'}->{$Name} = $Node ) ;
+
+  $env->{'uHTML.MacroBody'}->{$Name} = _findMacroBody( $env->{'uHTML.Macros'}->{$Name} = $Node->copy() ) ;
 
   if( $Node->testAttr( 'attributes' ) )
   {
